package com.javaseleniumtemplate.tests;

import com.javaseleniumtemplate.bases.TestBase;
import com.javaseleniumtemplate.flows.LoginFlows;
import com.javaseleniumtemplate.flows.DietaPadraoFlows;
import com.javaseleniumtemplate.pages.DietaPadraoPage;
import org.testng.annotations.Test;

public class DietaPadraoTests extends TestBase {

    DietaPadraoPage dietaPadraoPage;
    DietaPadraoFlows dietaPadraoFlows;
    LoginFlows loginFlows;


    //acessar a tela 'Dieta Padrão'
    //clicar no botão adicionar, preencher os campos: dieta padrão, nome dieta padrão,
    //clicar no campo especificação e selecionar 'normal', clicar no grupo fitness, preencher a descrição complementar e clicar em salvar
    //no filtro inicial procurar pelo código 0005, verificar se as informações da dieta padrão encontrada na primeira linha, correspondem as informação da dieta que foi adicionada
    //clicar no nome da dieta padrão, clicar em editar e verificar as informações da dieta padrão também correspondem as informações que foram adicionadas
    //no filtro inicial procurar pelo código 0005, clicar no nome da dieta, clicar no botão excluir, verificar a mensagem exibida na tela
    //clicar em sim, verificar a mensagem de excluído com sucesso e clicar em ok
    @Test
    public void adicionarExcluirDietaPadrao() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.adicionarDieta();
        dietaPadraoPage.verificarDietaAdicionada();
        dietaPadraoPage.excluirDieta();
    }


    //acessar a tela 'Dieta Padrão'
    //no filtro procurar pelo código 0004, clicar no nome da dieta padrão, clicar no botão editar, verificar se o campo dieta padrão está desabilitado
    //alterar o nome da dieta padrão, verificar a lista de opções do campo especificação, selecionar a especificação 'dieta especial'
    //alterar a descrição, verificar se o check-box de 'cardápio' e 'ativa' não estão selecionados, clicar nos mesmos e verificar se passam a estar selecionados
    //clicar em salvar, verificar a mensagem de salvo com sucesso exibida no canto da tela, clicar em voltar
    //no filtro procurar pelo código 0004, clicar no nome da dieta padrão, verificar se as informações alteradas foram salvar corretamente
    //clicar no nome da dieta padrão, clicar em editar e alterar as informações (nome da dieta, especificação, descrição, cardápio, ativa)
    //clicar em salvar, verificar a mensagem de salvo com sucesso, clicar em voltar
    @Test
    public void editarDietaPadrao() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.editarDieta();
        dietaPadraoPage.verificarDietaEditada();
        dietaPadraoPage.desfaserEdicaoDaDietaPadrao();
    }


    //acessar a tela 'Dieta Padrão'
    //no filtro procurar pelo código 0001, clicar no código da dieta padrão encontrada, clicar no botão excluir, verificar a mensagem exibida na tela
    //clicar em sim, verificar a mensagem exibida na tela informando que a exclusão não é permitida pois possuí registros filhos
    //clicar em ok, clicar em voltar
    @Test
    public void tentarExcluirDietaPadraoComRegFil() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.tentarExcluirDietaNaoPermitida();
    }


    //acessar a tela 'Dieta Padrão'
    //clicar no botão adicionar, preencher o campo dieta padrão com valor 1, preencher o campo nome da dieta padrão, selecionar uma especificação
    //clicar no botão salvar, verificar a mensagem exibida na tela informando que não é adicionar, pois o registro já existe
    //clicar no botão ok, clicar em cancelar
    @Test
    public void tentarAddDietaComCadigoExistente() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.tentarAddRegistroComCodigoExistente();
    }


    //acessar a tela 'Dieta Padrão'
    //clicar no botão adicionar, clicar em salvar, verificar a mensagem de campo obrigatório nos campos: nome dieta padrão, nome da dieta padrão, especificação
    //clicar em cancelar
    @Test
    public void camposObrigatorios() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.camposObrigatorios();
    }


    //acessar a tela 'Dieta Padrão'
    //no filtro procurar por 0002, clicar nome da dieta padrão encontrada, clicar no botão editar, clicar no check-box cardápio, clicar em salvar
    //verificar a mensagem exibida na tela informando que o cardápio não pode ser desmarcado, pois há cardápio com a dieta
    //clicar em ok, clicar em cancelar
    @Test
    public void cardapioNaoPodeSerDesmarcado() {
        dietaPadraoPage = new DietaPadraoPage();
        dietaPadraoFlows = new DietaPadraoFlows();
        loginFlows = new LoginFlows();

        loginFlows.efetuarLogin();
        dietaPadraoFlows.navegateTelaDietaPadrao();
        dietaPadraoPage.cardapioNaoPodeSerDesmarcado();
    }


}
